aboutsummaryrefslogtreecommitdiff
path: root/icing/join/join-processor.cc
diff options
context:
space:
mode:
authorTim Barron <tjbarron@google.com>2022-12-15 20:59:15 -0800
committerTim Barron <tjbarron@google.com>2022-12-15 20:59:15 -0800
commit3577cb81208482705d7d15a5347b826bb4bacdfe (patch)
treefd0208149785c2da69d0887d8acface964593579 /icing/join/join-processor.cc
parent94b21a83007fc0ce1bda6a7518d52f4ce07fb48d (diff)
downloadicing-3577cb81208482705d7d15a5347b826bb4bacdfe.tar.gz
Sync from upstream.
Descriptions: ====================================================================== Rename fullyQualifiedId to qualifiedId ====================================================================== Delete ResultState, which is dead code. ====================================================================== Implement support in the QueryVisitor for the property restrict operator (HAS) ====================================================================== Implement support in the QueryVisitor for implicit and, 'AND' and 'OR'. ====================================================================== Implement support in the QueryVisitor for NOT. ====================================================================== Implement support in the QueryVisitor for single term and single verbatim term queries. ====================================================================== Bug: 208654892 Bug: 256022027 Change-Id: I6c689dd7070ac0a9818b7425f3beab7258181049
Diffstat (limited to 'icing/join/join-processor.cc')
-rw-r--r--icing/join/join-processor.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/icing/join/join-processor.cc b/icing/join/join-processor.cc
index 71fa75f..9b17396 100644
--- a/icing/join/join-processor.cc
+++ b/icing/join/join-processor.cc
@@ -101,13 +101,13 @@ JoinProcessor::Join(
// parent_id_to_child_map.
for (ScoredDocumentHit& parent : parent_scored_document_hits) {
DocumentId parent_doc_id = kInvalidDocumentId;
- if (join_spec.parent_property_expression() == kFullyQualifiedIdExpr) {
+ if (join_spec.parent_property_expression() == kQualifiedIdExpr) {
parent_doc_id = parent.document_id();
} else {
// TODO(b/256022027): So far we only support kFullyQualifiedIdExpr for
// parent_property_expression, we could support more.
return absl_ports::UnimplementedError(absl_ports::StrCat(
- "Parent property expression must be ", kFullyQualifiedIdExpr));
+ "Parent property expression must be ", kQualifiedIdExpr));
}
// TODO(b/256022027): Derive final score from
@@ -101,13 +101,13 @@ JoinProcessor::Join(
parent_doc_id = parent.document_id();
} else {
- // TODO(b/256022027): So far we only support kFullyQualifiedIdExpr for
+ // TODO(b/256022027): So far we only support kQualifiedIdExpr for
// parent_property_expression, we could support more.
return absl_ports::UnimplementedError(absl_ports::StrCat(